AccountsStorageImpl class

Implemented types

Constructors

AccountsStorageImpl({required KVStorage kvStorage})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendAccount(AccountInfo account) Future<void>
override
getAccounts() Future<List<AccountInfo>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAccount(AccountInfo account) Future<void>
override
removeAccounts() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited