WebTransport class
- Implemented types
Constructors
- WebTransport(WebTransportConfig _config)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performWalletRequest<
T> (WalletRequest request, BCSSerializer< T> tSerializer, {AptosProvider? provider}) → Future<WalletResponse< T> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited