AptosConnectClientFactoryWeb class
- Implemented types
Constructors
- AptosConnectClientFactoryWeb({required String dAppName, required String? dAppImageUrl, required KVStorage storage, CryptoClient? cryptoClientOverride, AccountsStorage? accountStorageOverride})
Properties
- dAppImageUrl → String?
-
final
- dAppName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
make(
) → AptosConnectClient -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited