PromptMessage class

Constructors

PromptMessage({required String type, required Map<String, dynamic>? serializedValue})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializedValue Map<String, dynamic>?
final
type String
final

Methods

deserializeWalletResponse<T>(dynamic serializer) WalletResponse<T>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) PromptMessage?

Constants

approvalResponse → const String
pingRequest → const String
unauthorizedError → const String